#include <zephyr/kernel.h>
#include <zephyr/drivers/gpio.h>
#include <zephyr/drivers/led.h>
#include <zephyr/drivers/pwm.h>
#include <zephyr/logging/log.h>
#include <zephyr/sys/printk.h>

LOG_MODULE_REGISTER(led_pwm);

typedef enum {
    LED_OFF = 0,
    LED_ON
} led_on_off_t;

#if CONFIG_BOARD_NRF52DK_NRF52832
static const struct gpio_dt_spec _gLed0    = GPIO_DT_SPEC_GET(DT_ALIAS(led0), gpios);
static const struct pwm_dt_spec  _gPwmLed0 = PWM_DT_SPEC_GET(DT_ALIAS(pwm_led0));
#endif


int ledInit(void) {
    int ret;
#if CONFIG_BOARD_NRF52DK_NRF52832
    if (!device_is_ready(_gLed0.port)) {
        LOG_ERR("LED device %s is not ready", _gLed0.port->name);
        return -1;
    }

    ret = gpio_pin_configure_dt(&_gLed0, GPIO_OUTPUT);
    if (ret < 0) {
        LOG_ERR("Failed to configure the LED pin, error: %d", ret);
        return -1;
    }
#endif

    return 0;
}

#if CONFIG_BOARD_NRF52DK_NRF52832
int ledClear0(void) {
    gpio_pin_set_dt(&_gLed0, (int) LED_OFF);

    return 0;
}

int ledSet0(void) {
    gpio_pin_set_dt(&_gLed0, (int) LED_ON);

    return 0;
}
#endif